@@ -27,7 +27,6 @@
 #include "fm-error-reporting.h"
 
 #include <string.h>
-#include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnomevfs/gnome-vfs-result.h>
 #include <libnautilus-private/nautilus-file.h>
@@ -51,7 +50,7 @@ fm_report_error_loading_directory (NautilusFile *file,
 		return;
 	}
 
-	file_name = nautilus_file_get_name (file);
+	file_name = nautilus_file_get_display_name (file);
 
 	switch (error) {
 	case GNOME_VFS_ERROR_ACCESS_DENIED:
@@ -64,7 +63,7 @@ fm_report_error_loading_directory (NautilusFile *file,
 		break;
 	default:
 		/* We should invent decent error messages for every case we actually experience. */
-		g_warning ("Hit unhandled case %d (%s) in fm_report_error_loading_directory, tell sullivan@eazel.com", 
+		g_warning ("Hit unhandled case %d (%s) in fm_report_error_loading_directory", 
 			   error, gnome_vfs_result_to_string (error));
 		message = g_strdup_printf (_("Sorry, couldn't display all the contents of \"%s\"."), file_name);
 	}
@@ -92,7 +91,7 @@ fm_report_error_renaming_file (NautilusFile *file,
 	/* Truncate names for display since very long file names with no spaces
 	 * in them won't get wrapped, and can create insanely wide dialog boxes.
 	 */
-	original_name = nautilus_file_get_name (file);
+	original_name = nautilus_file_get_display_name (file);
 	original_name_truncated = eel_str_middle_truncate (original_name, MAXIMUM_DISPLAYED_FILE_NAME_LENGTH);
 	g_free (original_name);
 	
@@ -130,7 +129,7 @@ fm_report_error_renaming_file (NautilusFile *file,
 		break;
 	default:
 		/* We should invent decent error messages for every case we actually experience. */
-		g_warning ("Hit unhandled case %d (%s) in fm_report_error_renaming_file, tell sullivan@eazel.com", 
+		g_warning ("Hit unhandled case %d (%s) in fm_report_error_renaming_file", 
 			   error, gnome_vfs_result_to_string (error));
 		/* fall through */
 	case GNOME_VFS_ERROR_GENERIC:
@@ -157,7 +156,7 @@ fm_report_error_setting_group (NautilusFile *file,
 		return;
 	}
 
-	file_name = nautilus_file_get_name (file);
+	file_name = nautilus_file_get_display_name (file);
 
 	switch (error) {
 	case GNOME_VFS_ERROR_NOT_PERMITTED:
@@ -170,9 +169,9 @@ fm_report_error_setting_group (NautilusFile *file,
 		break;
 	default:
 		/* We should invent decent error messages for every case we actually experience. */
-		g_warning ("Hit unhandled case %d (%s) in fm_report_error_setting_group, tell sullivan@eazel.com", 
+		g_warning ("Hit unhandled case %d (%s) in fm_report_error_setting_group", 
 			   error, gnome_vfs_result_to_string (error));
-		file_name = nautilus_file_get_name (file);
+		file_name = nautilus_file_get_display_name (file);
 		message = g_strdup_printf (_("Sorry, couldn't change the group of \"%s\"."), file_name);
 		g_free (file_name);
 	}
@@ -195,7 +194,7 @@ fm_report_error_setting_owner (NautilusFile *file,
 		return;
 	}
 
-	file_name = nautilus_file_get_name (file);
+	file_name = nautilus_file_get_display_name (file);
 
 	switch (error) {
 	case GNOME_VFS_ERROR_READ_ONLY_FILE_SYSTEM:
@@ -204,7 +203,7 @@ fm_report_error_setting_owner (NautilusFile *file,
 		break;
 	default:
 		/* We should invent decent error messages for every case we actually experience. */
-		g_warning ("Hit unhandled case %d (%s) in fm_report_error_setting_owner, tell sullivan@eazel.com", 
+		g_warning ("Hit unhandled case %d (%s) in fm_report_error_setting_owner", 
 			   error, gnome_vfs_result_to_string (error));
 		message = g_strdup_printf (_("Sorry, couldn't change the owner of \"%s\"."), file_name);
 	}
@@ -227,7 +226,7 @@ fm_report_error_setting_permissions (NautilusFile *file,
 		return;
 	}
 
-	file_name = nautilus_file_get_name (file);
+	file_name = nautilus_file_get_display_name (file);
 
 	switch (error) {
 	case GNOME_VFS_ERROR_READ_ONLY_FILE_SYSTEM:
@@ -236,7 +235,7 @@ fm_report_error_setting_permissions (NautilusFile *file,
 		break;
 	default:
 		/* We should invent decent error messages for every case we actually experience. */
-		g_warning ("Hit unhandled case %d (%s) in fm_report_error_setting_permissions, tell sullivan@eazel.com", 
+		g_warning ("Hit unhandled case %d (%s) in fm_report_error_setting_permissions", 
 			   error, gnome_vfs_result_to_string (error));
 		message = g_strdup_printf (_("Sorry, couldn't change the permissions of \"%s\"."), file_name);
 	}
@@ -254,7 +253,7 @@ rename_callback (NautilusFile *file, GnomeVFSResult result, gpointer callback_da
 
 	g_assert (NAUTILUS_IS_FILE (file));
 	g_assert (callback_data == NULL);
-	name = gtk_object_get_data (GTK_OBJECT (file), NEW_NAME_TAG);
+	name = g_object_get_data (G_OBJECT (file), NEW_NAME_TAG);
 	g_assert (name != NULL);
 
 	/* If rename failed, notify the user. */
@@ -274,7 +273,7 @@ cancel_rename (NautilusFile *file)
 {
 	char *name;
 
-	name = gtk_object_get_data (GTK_OBJECT (file), NEW_NAME_TAG);
+	name = g_object_get_data (G_OBJECT (file), NEW_NAME_TAG);
 	if (name == NULL) {
 		return;
 	}
@@ -284,7 +283,7 @@ cancel_rename (NautilusFile *file)
 	eel_timed_wait_stop (cancel_rename_callback, file);
 
 	/* Let go of file name. */
-	gtk_object_remove_data (GTK_OBJECT (file), NEW_NAME_TAG);
+	g_object_set_data (G_OBJECT (file), NEW_NAME_TAG, NULL);
 }
 
 void
@@ -300,20 +299,20 @@ fm_rename_file (NautilusFile *file,
 	cancel_rename (file);
 
 	/* Attach the new name to the file. */
-	gtk_object_set_data_full (GTK_OBJECT (file),
-				  NEW_NAME_TAG,
-				  g_strdup (new_name),
-				  g_free);
+	g_object_set_data_full (G_OBJECT (file),
+				NEW_NAME_TAG,
+				g_strdup (new_name),
+				g_free);
 
 	/* Start the timed wait to cancel the rename. */
-	old_name = nautilus_file_get_name (file);
+	old_name = nautilus_file_get_display_name (file);
 	wait_message = g_strdup_printf (_("Renaming \"%s\" to \"%s\"."),
 					old_name,
 					new_name);
 	g_free (old_name);
 	eel_timed_wait_start (cancel_rename_callback, file,
 				   _("Cancel Rename?"), wait_message,
-				   NULL); /* FIXME bugzilla.eazel.com 2395: Parent this? */
+				   NULL); /* FIXME bugzilla.gnome.org 42395: Parent this? */
 	g_free (wait_message);
 
 	/* Start the rename. */
