@@ -179,7 +179,7 @@ static void remove_pending_file                   (StartupData             *data
 static void append_bonobo_pages                   (FMPropertiesWindow *window);
 
 GNOME_CLASS_BOILERPLATE (FMPropertiesWindow, fm_properties_window,
-			 GtkDialog, GTK_TYPE_DIALOG)
+			 GtkWindow, GTK_TYPE_WINDOW);
 
 typedef struct {
 	NautilusFile *file;
@@ -417,7 +417,8 @@ name_field_update_to_match_file (NautilusEntry *name_field)
 	 * aspect of the file might have), then don't clobber changes.
 	 */
 	current_name = nautilus_file_get_display_name (file);
-	if (eel_strcmp (original_name, current_name) != 0) {
+	if (original_name == NULL || 
+	    eel_strcmp (original_name, current_name) != 0) {
 		g_object_set_data_full (G_OBJECT (name_field),
 					"original_name",
 					current_name,
@@ -1281,9 +1282,9 @@ schedule_directory_contents_update (FMPropertiesWindow *window)
 
 	if (window->details->update_directory_contents_timeout_id == 0) {
 		window->details->update_directory_contents_timeout_id
-			= gtk_timeout_add (DIRECTORY_CONTENTS_UPDATE_INTERVAL,
-					   update_directory_contents_callback,
-					   window);
+			= g_timeout_add (DIRECTORY_CONTENTS_UPDATE_INTERVAL,
+					 update_directory_contents_callback,
+					 window);
 	}
 }
 
@@ -1585,6 +1586,17 @@ should_show_link_target (FMPropertiesWindow *window)
 	return FALSE;
 }
 
+static gboolean
+should_show_free_space (FMPropertiesWindow *window)
+{
+	if (nautilus_file_is_local (window->details->target_file)
+	    && nautilus_file_is_directory (window->details->target_file)) {
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 static void
 create_basic_page (FMPropertiesWindow *window)
 {
@@ -1693,6 +1705,11 @@ create_basic_page (FMPropertiesWindow *window)
 		append_title_value_pair (table, _("Size:"), target_file, "size");
 	}
 	append_title_and_ellipsizing_value (table, _("Location:"), target_file, "where");
+	
+	if (should_show_free_space (window)) {
+		append_title_and_ellipsizing_value (table, _("Volume:"), target_file, "volume");
+		append_title_value_pair (table, _("Free space:"), target_file, "free_space");
+	}
 	if (should_show_link_target (window)) {
 		append_title_and_ellipsizing_value (table, _("Link target:"), target_file, "link_target");
 	}
@@ -2369,6 +2386,7 @@ create_properties_window (StartupData *startup_data)
 	FMPropertiesWindow *window;
 	GList *attributes;
 	GtkWidget *vbox;
+	GtkWidget *hbox;
 	GtkWidget *button;
 
 	window = FM_PROPERTIES_WINDOW (gtk_widget_new (fm_properties_window_get_type (), NULL));
@@ -2414,7 +2432,7 @@ create_properties_window (StartupData *startup_data)
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 	gtk_widget_show (vbox);
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG(window)->vbox), 
+	gtk_container_add (GTK_CONTAINER (window),
 			   GTK_WIDGET (vbox));
 
 	/* Create the notebook tabs. */
@@ -2436,15 +2454,16 @@ create_properties_window (StartupData *startup_data)
 
 	/* append pages from available views */
 	append_bonobo_pages (window);
-	
-	/* Create buttons for action area. */
-	gtk_dialog_set_has_separator (GTK_DIALOG (window), FALSE);
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (GTK_DIALOG (window)->action_area),
-				   GTK_BUTTONBOX_EDGE);
+
+	/* Create box for help and close buttons. */
+	hbox = gtk_hbutton_box_new ();
+	gtk_widget_show (hbox);
+	gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (hbox), FALSE, TRUE, 5);
+	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbox), GTK_BUTTONBOX_EDGE);
 
 	button = gtk_button_new_from_stock (GTK_STOCK_HELP);
  	gtk_widget_show (button);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->action_area), GTK_WIDGET (button),
+	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (button),
 			    FALSE, TRUE, 0);
 	g_signal_connect_object (button, "clicked",
 				 G_CALLBACK (help_button_callback),
@@ -2452,7 +2471,7 @@ create_properties_window (StartupData *startup_data)
 	
 	button = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
 	gtk_widget_show (button);
-	gtk_box_pack_end (GTK_BOX (GTK_DIALOG (window)->action_area), GTK_WIDGET (button),
+	gtk_box_pack_end (GTK_BOX (hbox), GTK_WIDGET (button),
 			    FALSE, TRUE, 0);
 	g_signal_connect_swapped (button, "clicked",
 				  G_CALLBACK (gtk_widget_destroy),
@@ -2661,7 +2680,7 @@ real_destroy (GtkObject *object)
 	window->details->special_flags_widgets = NULL;
 
 	if (window->details->update_directory_contents_timeout_id != 0) {
-		gtk_timeout_remove (window->details->update_directory_contents_timeout_id);
+		g_source_remove (window->details->update_directory_contents_timeout_id);
 		window->details->update_directory_contents_timeout_id = 0;
 	}
 
@@ -2746,4 +2765,6 @@ static void
 fm_properties_window_instance_init (FMPropertiesWindow *window)
 {
 	window->details = g_new0 (FMPropertiesWindowDetails, 1);
+
+	eel_gtk_window_set_up_close_accelerator (GTK_WINDOW (window));
 }
