@@ -63,11 +63,11 @@ typedef struct {
 					  NautilusSwitchableNavigationBarMode mode);
 } NautilusSwitchableNavigationBarClass;
 
-GtkType    			    nautilus_switchable_navigation_bar_get_type	(void);
+GType    			    nautilus_switchable_navigation_bar_get_type	(void);
 GtkWidget* 			    nautilus_switchable_navigation_bar_new     	(NautilusWindow *window);
 NautilusSwitchableNavigationBarMode nautilus_switchable_navigation_bar_get_mode (NautilusSwitchableNavigationBar     *switchable_navigation_bar);
 void       			    nautilus_switchable_navigation_bar_set_mode (NautilusSwitchableNavigationBar     *switchable_navigation_bar,
 								 		 NautilusSwitchableNavigationBarMode  mode);
-
+void				    nautilus_switchable_navigation_bar_activate (NautilusSwitchableNavigationBar     *switchable_navigation_bar);
 
 #endif /* NAUTILUS_SWITCHABLE_NAVIGATION_BAR_H */
