@@ -213,7 +213,7 @@ nautilus_window_show_location_bar_temporarily (NautilusWindow *window,
 					       gboolean in_search_mode)
 {
 	if (!nautilus_window_location_bar_showing (window)) {
-		nautilus_window_show_location_bar (window);
+		nautilus_window_show_location_bar (window, FALSE);
 		window->details->temporary_navigation_bar = TRUE;
 	}
 	nautilus_window_set_search_mode 
@@ -461,9 +461,9 @@ view_menu_show_hide_location_bar_state_changed_callback (BonoboUIComponent *comp
         }
 
 	if (!strcmp (state, "1")) {
-		nautilus_window_show_location_bar (window);
+		nautilus_window_show_location_bar (window, TRUE);
 	} else {
-		nautilus_window_hide_location_bar (window);
+		nautilus_window_hide_location_bar (window, TRUE);
 	}
 }
 
@@ -583,7 +583,7 @@ preferences_callback (BonoboUIComponent *component,
 
 	window = GTK_WINDOW (user_data);
 
-	nautilus_file_management_properties_dialog_show (G_CALLBACK (preferences_respond_callback));
+	nautilus_file_management_properties_dialog_show (G_CALLBACK (preferences_respond_callback), window);
 }
 
 static void
@@ -1281,7 +1281,7 @@ void
 nautilus_window_remove_bookmarks_menu_callback (NautilusWindow *window)
 {
         if (window->details->refresh_bookmarks_menu_idle_id != 0) {
-                gtk_idle_remove (window->details->refresh_bookmarks_menu_idle_id);
+                g_source_remove (window->details->refresh_bookmarks_menu_idle_id);
 		window->details->refresh_bookmarks_menu_idle_id = 0;
         }
 }
@@ -1290,7 +1290,7 @@ void
 nautilus_window_remove_go_menu_callback (NautilusWindow *window)
 {
         if (window->details->refresh_go_menu_idle_id != 0) {
-                gtk_idle_remove (window->details->refresh_go_menu_idle_id);
+                g_source_remove (window->details->refresh_go_menu_idle_id);
 		window->details->refresh_go_menu_idle_id = 0;
         }
 }
@@ -1362,8 +1362,8 @@ schedule_refresh_bookmarks_menu (NautilusWindow *window)
 
 	if (window->details->refresh_bookmarks_menu_idle_id == 0) {
                 window->details->refresh_bookmarks_menu_idle_id
-                        = gtk_idle_add (refresh_bookmarks_menu_idle_callback,
-                                        window);
+                        = g_idle_add (refresh_bookmarks_menu_idle_callback,
+				      window);
 	}	
 }
 
@@ -1421,7 +1421,7 @@ schedule_refresh_go_menu (NautilusWindow *window)
 
 	if (window->details->refresh_go_menu_idle_id == 0) {
                 window->details->refresh_go_menu_idle_id
-                        = gtk_idle_add (refresh_go_menu_idle_callback,
-                                        window);
+                        = g_idle_add (refresh_go_menu_idle_callback,
+				      window);
 	}	
 }
