@@ -87,7 +87,6 @@
  */
 #include "nautilus-desktop-window.h"
 
-#define STATUS_BAR_CLEAR_TIMEOUT 10000	/* milliseconds */
 #define MAX_HISTORY_ITEMS 50
 
 /* FIXME bugzilla.gnome.org 41245: hardwired sizes */
@@ -338,7 +337,6 @@ nautilus_window_clear_status (gpointer callback_data)
 	window = NAUTILUS_WINDOW (callback_data);
 
 	bonobo_ui_component_set_status (window->details->status_ui, NULL, NULL);
-	window->status_bar_clear_id = 0;
 
 	return FALSE;
 }
@@ -346,17 +344,10 @@ nautilus_window_clear_status (gpointer callback_data)
 void
 nautilus_window_set_status (NautilusWindow *window, const char *text)
 {
-	if (window->status_bar_clear_id != 0) {
-		g_source_remove (window->status_bar_clear_id);
-	}
-
 	if (text != NULL && text[0] != '\0') {
 		bonobo_ui_component_set_status (window->details->status_ui, text, NULL);
-		window->status_bar_clear_id = g_timeout_add
-			(STATUS_BAR_CLEAR_TIMEOUT, nautilus_window_clear_status, window);
 	} else {
 		nautilus_window_clear_status (window);
-		window->status_bar_clear_id = 0;
 	}
 }
 
@@ -393,7 +384,7 @@ navigation_bar_location_changed_callback (GtkWidget *widget,
 
 	if (window->details->temporary_navigation_bar) {
 		if (nautilus_window_location_bar_showing (window)) {
-			nautilus_window_hide_location_bar (window);
+			nautilus_window_hide_location_bar (window, FALSE);
 		}
 		window->details->temporary_navigation_bar = FALSE;
 	}
@@ -611,9 +602,8 @@ side_panel_set_open (GtkWidget *view,
 }
 
 static void
-side_pane_switch_page_callback (NautilusSidePane *side_pane,
-				GtkWidget *panel,
-				NautilusWindow *window)
+set_current_side_panel (NautilusWindow *window,
+			GtkWidget *panel)
 {
 	if (window->details->current_side_panel) {
 		side_panel_set_open (window->details->current_side_panel, 
@@ -626,21 +616,30 @@ side_pane_switch_page_callback (NautilusSidePane *side_pane,
 	eel_add_weak_pointer (&window->details->current_side_panel);
 }
 
+static void
+side_pane_switch_page_callback (NautilusSidePane *side_pane,
+				GtkWidget *panel,
+				NautilusWindow *window)
+{
+	const char *view_iid;
+
+	set_current_side_panel (window, panel);
+
+	if (NAUTILUS_IS_VIEW_FRAME (panel)) {
+		view_iid = nautilus_view_frame_get_view_iid (NAUTILUS_VIEW_FRAME (panel));
+		eel_preferences_set (NAUTILUS_PREFERENCES_SIDE_PANE_VIEW,
+				     view_iid);
+		
+	} else {
+		eel_preferences_set (NAUTILUS_PREFERENCES_SIDE_PANE_VIEW, "");
+	}
+}
+
 static void
 nautilus_window_set_up_sidebar (NautilusWindow *window)
 {
 	window->sidebar = nautilus_side_pane_new ();
 
-	g_signal_connect (window->sidebar,
-			  "close_requested",
-			  G_CALLBACK (side_pane_close_requested_callback),
-			  window);
-
-	g_signal_connect (window->sidebar,
-			  "switch_page",
-			  G_CALLBACK (side_pane_switch_page_callback),
-			  window);
-
 	gtk_paned_pack1 (GTK_PANED (window->content_hbox),
 			 GTK_WIDGET (window->sidebar),
 			 FALSE, TRUE);
@@ -663,14 +662,24 @@ nautilus_window_set_up_sidebar (NautilusWindow *window)
 	g_signal_connect_object (window->information_panel, "location_changed",
 				 G_CALLBACK (go_to_callback), window, 0);
 
-	gtk_widget_show (GTK_WIDGET (window->information_panel));
-
+	/* Set up the sidebar panels. */
 	nautilus_side_pane_add_panel (NAUTILUS_SIDE_PANE (window->sidebar), 
 				      GTK_WIDGET (window->information_panel),
 				      _("Information"));
 
-	/* Set up the sidebar panels. */
 	add_sidebar_panels (window);
+
+	g_signal_connect (window->sidebar,
+			  "close_requested",
+			  G_CALLBACK (side_pane_close_requested_callback),
+			  window);
+
+	g_signal_connect (window->sidebar,
+			  "switch_page",
+			  G_CALLBACK (side_pane_switch_page_callback),
+			  window);
+	
+	gtk_widget_show (GTK_WIDGET (window->information_panel));
 	
 	gtk_widget_show (GTK_WIDGET (window->sidebar));
 }
@@ -678,6 +687,10 @@ nautilus_window_set_up_sidebar (NautilusWindow *window)
 static void
 nautilus_window_tear_down_sidebar (NautilusWindow *window)
 {
+	g_signal_handlers_disconnect_by_func (window->sidebar,
+					      side_pane_switch_page_callback,
+					      window);
+
 	nautilus_window_set_sidebar_panels (window, NULL);
 	gtk_widget_destroy (GTK_WIDGET (window->sidebar));
 	window->sidebar = NULL;
@@ -940,7 +953,7 @@ nautilus_window_finalize (GObject *object)
 	nautilus_window_remove_go_menu_callback (window);
 
 	if (window->details->ui_idle_id != 0) {
-		gtk_idle_remove (window->details->ui_idle_id);
+		g_source_remove (window->details->ui_idle_id);
 	}
 
 	if (window->details->shell_ui != NULL) {
@@ -971,19 +984,17 @@ nautilus_window_finalize (GObject *object)
 		g_object_unref (window->last_location_bookmark);
 	}
 
-	if (window->status_bar_clear_id != 0) {
-		g_source_remove (window->status_bar_clear_id);
-	}
-
 	bonobo_object_unref (window->details->ui_container);
 
 	if (window->details->location_change_at_idle_id != 0) {
-		gtk_idle_remove (window->details->location_change_at_idle_id);
+		g_source_remove (window->details->location_change_at_idle_id);
 	}
 
 	g_free (window->details->title);
 	
 	g_free (window->details);
+	
+	g_free (window->last_geometry);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -995,14 +1006,17 @@ nautilus_window_save_geometry (NautilusWindow *window)
 
 	g_assert (NAUTILUS_IS_WINDOW (window));
 
-	geometry_string = eel_gtk_window_get_geometry_string (GTK_WINDOW (window));
-
-	nautilus_file_set_metadata (window->details->viewed_file,
-				    NAUTILUS_METADATA_KEY_WINDOW_GEOMETRY,
-				    NULL,
-				    geometry_string);
-				    
-	g_free (geometry_string);
+	if (GTK_WIDGET(window)->window &&
+	    !(gdk_window_get_state (GTK_WIDGET(window)->window) & GDK_WINDOW_STATE_MAXIMIZED)) {
+		geometry_string = eel_gtk_window_get_geometry_string (GTK_WINDOW (window));
+		
+		nautilus_file_set_metadata (window->details->viewed_file,
+					    NAUTILUS_METADATA_KEY_WINDOW_GEOMETRY,
+					    NULL,
+					    geometry_string);
+		
+		g_free (geometry_string);
+	}
 }
 
 void
@@ -1178,7 +1192,7 @@ add_view_as_bonobo_menu_item (NautilusWindow *window,
 		(window->details->shell_ui,
 		 placeholder_path,
 		 index,
-		 identifier->view_as_label,
+		 identifier->view_as_label_with_mnemonic,
 		 "viewers group");
 
 	tip = g_strdup_printf (_("Display this location with \"%s\""),
@@ -1521,22 +1535,33 @@ nautilus_window_add_sidebar_panel (NautilusWindow *window,
 				   NautilusViewFrame *sidebar_panel)
 {
 	char *label;
+	const char *view_iid;
+	char *default_iid;
 
 	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 	g_return_if_fail (NAUTILUS_IS_VIEW_FRAME (sidebar_panel));
 	g_return_if_fail (NAUTILUS_IS_SIDE_PANE (window->sidebar));
-	g_return_if_fail (g_list_find (window->sidebar_panels, sidebar_panel) == NULL);
-	
+	g_return_if_fail (g_list_find (window->sidebar_panels, sidebar_panel) == NULL);	
+
 	label = nautilus_view_frame_get_label (sidebar_panel);
 	
 	nautilus_side_pane_add_panel (window->sidebar, 
 				      GTK_WIDGET (sidebar_panel), 
 				      label);
-
 	g_free (label);
 
 	g_object_ref (sidebar_panel);
 	window->sidebar_panels = g_list_prepend (window->sidebar_panels, sidebar_panel);
+
+	view_iid = nautilus_view_frame_get_view_iid (sidebar_panel);
+	default_iid = eel_preferences_get (NAUTILUS_PREFERENCES_SIDE_PANE_VIEW);
+
+	if (view_iid && default_iid && !strcmp (view_iid, default_iid)) {
+		nautilus_side_pane_show_panel (window->sidebar,
+					       GTK_WIDGET (sidebar_panel));
+	}	
+
+	g_free (default_iid);
 }
 
 void
@@ -1944,6 +1969,10 @@ add_sidebar_panels (NautilusWindow *window)
 	identifier_list = nautilus_sidebar_get_all_sidebar_panel_view_identifiers ();
 	nautilus_window_set_sidebar_panels (window, identifier_list);
 	nautilus_view_identifier_list_free (identifier_list);
+
+	set_current_side_panel
+		(window, 
+		 nautilus_side_pane_get_current_panel (window->sidebar));
 }
 
 static void 
@@ -1984,18 +2013,22 @@ dock_item_showing (NautilusWindow *window, const char *dock_item_path)
 }
 
 void 
-nautilus_window_hide_location_bar (NautilusWindow *window)
+nautilus_window_hide_location_bar (NautilusWindow *window, gboolean save_preference)
 {
 	window->details->temporary_navigation_bar = FALSE;
 	hide_dock_item (window, LOCATION_BAR_PATH);
-	eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_LOCATION_BAR, FALSE);
+	if (save_preference) {
+		eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_LOCATION_BAR, FALSE);
+	}
 }
 
 void 
-nautilus_window_show_location_bar (NautilusWindow *window)
+nautilus_window_show_location_bar (NautilusWindow *window, gboolean save_preference)
 {
 	show_dock_item (window, LOCATION_BAR_PATH);
-	eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_LOCATION_BAR, TRUE);
+	if (save_preference) {
+		eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_LOCATION_BAR, TRUE);
+	}
 }
 
 gboolean
@@ -2135,9 +2168,9 @@ nautilus_window_show (GtkWidget *widget)
 	}
 
 	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_LOCATION_BAR)) {
-		nautilus_window_show_location_bar (window);
+		nautilus_window_show_location_bar (window, FALSE);
 	} else {
-		nautilus_window_hide_location_bar (window);
+		nautilus_window_hide_location_bar (window, FALSE);
 	}
 
 	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_STATUS_BAR)) {
